Running a test problem
======================

Open a terminal window and navigate to the folder where you installed beluga. Type the following commands to run the Brachistochrone problem::

    cd examples/brachistochrone
    python brachisto.py

The solver will proceed to solve the Brachistochrone problem.
